==> jc-1.4.0.tar.gz: javax/swing/Box.h <==
// public class javax.swing.Box

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1f09acd8bda08b5d javax_swing_Box
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent

// header file dependencies
// @dep_header javax_swing_JComponent

#include "javax/swing/JComponent.h"

#ifndef _JC_javax_swing_Box_H_
#define _JC_javax_swing_Box_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_LayoutManager$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleContext$object;
struct _jc_javax_swing_Box$object;

// Typedefs
typedef struct _jc_javax_swing_Box$sub_refs	_jc_javax_swing_Box$sub_refs;
typedef struct _jc_javax_swing_Box$sub_nonrefs	_jc_javax_swing_Box$sub_nonrefs;
typedef struct _jc_javax_swing_Box$refs	_jc_javax_swing_Box$refs;
typedef struct _jc_javax_swing_Box$nonrefs	_jc_javax_swing_Box$nonrefs;
typedef struct _jc_javax_swing_Box$object	_jc_javax_swing_Box$object;

typedef struct _jc_javax_swing_Box$fields_struct	_jc_javax_swing_Box$fields_struct;
typedef const struct _jc_javax_swing_Box$vmethods	_jc_javax_swing_Box$vmethods;
typedef const struct _jc_javax_swing_Box$vtable	_jc_javax_swing_Box$vtable;
typedef const struct _jc_javax_swing_Box$vtype	_jc_javax_swing_Box$vtype;

// Class fields structure
struct _jc_javax_swing_Box$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_Box$fields_struct _jc_javax_swing_Box$class_fields;

// Constructors
extern void _jc_javax_swing_Box$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_swing_Box$object *, jint);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleContext$object *_jc_javax_swing_Box$method$getAccessibleContext$99df33b6e138b2ea(_jc_env *, struct _jc_javax_swing_Box$object *);
extern void _jc_javax_swing_Box$method$setLayout$ae8ea942ea924bdf(_jc_env *, struct _jc_javax_swing_Box$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Box$method_info$getAccessibleContext$99df33b6e138b2ea;
extern _jc_method _jc_javax_swing_Box$method_info$setLayout$ae8ea942ea924bdf;

// Static methods
extern struct _jc_java_awt_Component$object *_jc_javax_swing_Box$method$createGlue$74f60cc3a3b298b2(_jc_env *);
extern struct _jc_javax_swing_Box$object *_jc_javax_swing_Box$method$createHorizontalBox$f72863117ac58b27(_jc_env *);
extern struct _jc_java_awt_Component$object *_jc_javax_swing_Box$method$createHorizontalGlue$71f301a7ae22b0f7(_jc_env *);
extern struct _jc_java_awt_Component$object *_jc_javax_swing_Box$method$createHorizontalStrut$5a05f2d34bb0e36b(_jc_env *, jint);
extern struct _jc_java_awt_Component$object *_jc_javax_swing_Box$method$createRigidArea$df561bef5187b769(_jc_env *, struct _jc_java_awt_Dimension$object *);
extern struct _jc_javax_swing_Box$object *_jc_javax_swing_Box$method$createVerticalBox$49e2b8a8abaf7699(_jc_env *);
extern struct _jc_java_awt_Component$object *_jc_javax_swing_Box$method$createVerticalGlue$5122539c504bc27d(_jc_env *);
extern struct _jc_java_awt_Component$object *_jc_javax_swing_Box$method$createVerticalStrut$7c1f59ae8f39f40c(_jc_env *, jint);

// Virtual methods structure
struct _jc_javax_swing_Box$vmethods {
	struct _jc_javax_accessibility_AccessibleContext$object	*(*getAccessibleContext$99df33b6e138b2ea)(_jc_env *, struct _jc_javax_swing_Box$object *);
	void	(*setLayout$ae8ea942ea924bdf)(_jc_env *, struct _jc_javax_swing_Box$object *, struct _jc_object *);
};

// Vtable
struct _jc_javax_swing_Box$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_Box$vmethods	javax_swing_Box;
};

// Vtype
struct _jc_javax_swing_Box$vtype {
	_jc_type			type;
	_jc_javax_swing_Box$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Box$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_Box$refs {
    _jc_javax_swing_Box$sub_refs	javax_swing_Box;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Box$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Box$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_Box$sub_nonrefs	javax_swing_Box;
};

// Object instance structure
struct _jc_javax_swing_Box$object {
	_jc_javax_swing_Box$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Box$vtype	*vtype;
	_jc_javax_swing_Box$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Box$vtype _jc_javax_swing_Box$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Box, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Box$class_object;

#endif	/* _JC_javax_swing_Box_H_ */

==> jc-1.4.5.tar.gz: javax/swing/Box.h <==
// public class javax.swing.Box

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1f09acd8bda08b5d javax_swing_Box
// @dep_class c84352ee73c7cec1 javax_swing_JComponent

// header file dependencies
// @dep_header javax_swing_JComponent

#include "javax/swing/JComponent.h"

#ifndef _JC_javax_swing_Box_H_
#define _JC_javax_swing_Box_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_LayoutManager$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleContext$object;
struct _jc_javax_swing_Box$object;

// Typedefs
typedef struct _jc_javax_swing_Box$sub_refs	_jc_javax_swing_Box$sub_refs;
typedef struct _jc_javax_swing_Box$sub_nonrefs	_jc_javax_swing_Box$sub_nonrefs;
typedef struct _jc_javax_swing_Box$refs	_jc_javax_swing_Box$refs;
typedef struct _jc_javax_swing_Box$nonrefs	_jc_javax_swing_Box$nonrefs;
typedef struct _jc_javax_swing_Box$object	_jc_javax_swing_Box$object;

typedef struct _jc_javax_swing_Box$fields_struct	_jc_javax_swing_Box$fields_struct;
typedef const struct _jc_javax_swing_Box$vmethods	_jc_javax_swing_Box$vmethods;
typedef const struct _jc_javax_swing_Box$vtable	_jc_javax_swing_Box$vtable;
typedef const struct _jc_javax_swing_Box$vtype	_jc_javax_swing_Box$vtype;

// Class fields structure
struct _jc_javax_swing_Box$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_Box$fields_struct _jc_javax_swing_Box$class_fields;

// Constructors
extern void _jc_javax_swing_Box$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_swing_Box$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleContext$object *_jc_javax_swing_Box$method$getAccessibleContext$99df33b6e138b2ea(_jc_env *, struct _jc_javax_swing_Box$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_Box$method$setLayout$ae8ea942ea924bdf(_jc_env *, struct _jc_javax_swing_Box$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Box$method_info$getAccessibleContext$99df33b6e138b2ea;
extern _jc_method _jc_javax_swing_Box$method_info$setLayout$ae8ea942ea924bdf;

// Static methods
extern struct _jc_java_awt_Component$object *_jc_javax_swing_Box$method$createGlue$74f60cc3a3b298b2(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_Box$object *_jc_javax_swing_Box$method$createHorizontalBox$f72863117ac58b27(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Component$object *_jc_javax_swing_Box$method$createHorizontalGlue$71f301a7ae22b0f7(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Component$object *_jc_javax_swing_Box$method$createHorizontalStrut$5a05f2d34bb0e36b(_jc_env *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Component$object *_jc_javax_swing_Box$method$createRigidArea$df561bef5187b769(_jc_env *, struct _jc_java_awt_Dimension$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_Box$object *_jc_javax_swing_Box$method$createVerticalBox$49e2b8a8abaf7699(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Component$object *_jc_javax_swing_Box$method$createVerticalGlue$5122539c504bc27d(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Component$object *_jc_javax_swing_Box$method$createVerticalStrut$7c1f59ae8f39f40c(_jc_env *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_Box$vmethods {
	struct _jc_javax_accessibility_AccessibleContext$object	*(*getAccessibleContext$99df33b6e138b2ea)(_jc_env *, struct _jc_javax_swing_Box$object *) _JC_JCNI_ATTR;
	void	(*setLayout$ae8ea942ea924bdf)(_jc_env *, struct _jc_javax_swing_Box$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_Box$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_Box$vmethods	javax_swing_Box;
};

// Vtype
struct _jc_javax_swing_Box$vtype {
	_jc_type			type;
	_jc_javax_swing_Box$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Box$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_Box$refs {
    _jc_javax_swing_Box$sub_refs	javax_swing_Box;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Box$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Box$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_Box$sub_nonrefs	javax_swing_Box;
};

// Object instance structure
struct _jc_javax_swing_Box$object {
	_jc_javax_swing_Box$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Box$vtype	*vtype;
	_jc_javax_swing_Box$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Box$vtype _jc_javax_swing_Box$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Box, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Box$class_object;

#endif	/* _JC_javax_swing_Box_H_ */
